oceanum package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   oceanum.datamesh
   oceanum.storage

Submodules
----------

oceanum.cli module
------------------

.. automodule:: oceanum.cli
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: oceanum
   :members:
   :undoc-members:
   :show-inheritance:
